---
title: LogarithmPlotter
description: 2D plotter software to make BODE plots, sequences and repartition functions.
layout: app

HeaderImage: /icons/apps/webp/logarithmplotter.webp
SectionHeader:
    AppIndex: logarithmplotter
    Background: |
        radial-gradient(ellipse at 20%, #dddddddf, #eeeeeedf 20%, transparent 85%),
        linear-gradient(to bottom, #fff, #fff 4em, transparent 8em),
        repeating-linear-gradient(#fafafa1f, #fafafa1f min(78px, calc(10% - 2px)), #bbb min(80px, 10%)),
        repeating-linear-gradient(0.25turn, #fafafa1f, #fafafa1f min(78px, calc(10% - 2px)), #bbb min(80px, 10%))
            
    # linear-gradient(to bottom right, transparent 90%, red calc(90% + 1px), red 95%, transparent calc(95% + 1px)),
    ShowPlatforms: true
    TextWhite: false
    Links:
        - Icon: lookup
          Title: Discover
          URL: "#about-section"
        - Icon: download
          Title: Download
          URL: "#download-section"

About:
    Title: Discover LogarithmPlotter
    Content: |
        LogarithmPlotter is, as it's name suggests, a plotter made with logarithmic scales in mind. With an object system similar to [Geogebra](https://geogebra.org)'s, it allows dynamic creation of plots with very few limitations.    
        It's primary use is to quickly create [asymptotic Bode plots](https://en.wikipedia.org/wiki/Bode_plot), but it's extensible nature and ability to switch to non-logarithmic scales allow it to create other things with it, like sequences or statistical repartition functions.
          
Sections:
    - Type: image|text
      Image: en/logarithmplotter/objects.webp
      Alt: Object management panel.
      Content: |
        # Object Management System
        LogarithmPlotter works with objects to create complex features and diagrams, as well as quickly manage what to display.   
        This system allows you to create, position, edit and delete objects in an instant.
    - Type: text|image
      Image: en/logarithmplotter/object-settings.webp
      Alt: Settings panel of an object.
      Content: |
        # Complete object edition
        Editing objects has been made very simple yet complete and easily extendable with a settings page that allows you to edit all properties of an object.   
        Properties are made to be backwards and forward compatible to prevent data corruption when opening a file made with a different version of LogarithmPlotter.
    - Type: image|text
      Image: en/logarithmplotter/history.webp
      Alt: History panel.
      Content: |
        # Advanced history system
        Featuring an advanced history system, LogarithmPlotter is extremely fast at undoing and redoing actions, as well as listing a complete list of actions history.   
        This system allows you to quickly rollback to a previous state of your diagram fairly quickly while displaying in fast mode all the modifications done in that span of time.   
        Another advantage of this system is that it allows history to be saved in your file directly while being extremely light on storage (LogarithmPlotter files, .lpf, rarely exceed a few kilobytes).
    - Type: text|image
      Image: en/logarithmplotter/settings.webp
      Alt: Settings panel.
      Content: |
        # Customize how your diagram looks
        LogarithmPlotter allows you to edit how your diagram looks in numerous ways, from the representation of the axis, to the size of elements and text as well as switching to normal scale mode from the logarithm one.    
        The settings section also features function buttons that can also be found in the menu bar, such as copying the diagram to the clipboard, or saving the plot.
    - Type: text
      Content: |
        ## Special thanks
        It's only thanks to these amazing people that LogarithmPlotter is available in so many languages.  
        - [Óvári](https://github.com/ovari) for the 🇭🇺 Hungarian translation.
        - [Allan Nordhøy](https://github.com/comradekingu) for the 🇳🇴 Norwegian translation.  
        If you want to see your own name here, you can contribute to the effort to translate LogarithmPlotter on [Weblate](https://hosted.weblate.org/engage/logarithmplotter/).


Technical:
    Links:
        - Title: Source code
          Icon: git
          URL: https://git.ad5001.eu/Ad5001/LogarithmPlotter
        - Title: Report a bug
          Icon: bug
          URL: https://git.ad5001.eu/Ad5001/LogarithmPlotter/issues
        - Title: Documentation
          Icon: documentation
          URL: https://git.ad5001.eu/Ad5001/LogarithmPlotter/wiki
        - Title: Help with translation
          Icon: lang
          URL: https://hosted.weblate.org/engage/logarithmplotter/
        - Title: Changelog
          Icon: documentation
          URL: https://git.ad5001.eu/Ad5001/LogarithmPlotter/src/branch/master/CHANGELOG.md#changelog

Download:
    Show: true
    Categories:
        - Name: win
          Title: Windows
          Platform: Windows
        - Name: macos
          Title: MacOSX
          Platform: MacOSX
        - Name: linux
          Title: Linux
          Platform: Linux
        - Name: all
          Title: All platforms*
          Platform: Universal
    Links:
        win:
            - Title: Installer software (.exe) (64 bits)
              Name: logarithmplotter-v<version>-setup.exe (101.2MiB)
              File: logarithmplotter-v<version>-setup.exe
        macos:
            - Title: Application Archive (.dmg)
              Name: LogarithmPlotter-v<version>-setup.dmg (114.6MiB)
              File: LogarithmPlotter-v<version>-setup.dmg
        linux:
            - Title: Flatpak (via Flathub)
              Index: eu.ad5001.LogarithmPlotter
            - Title: Snap
              Index: logarithmplotter
            - Title: Launchpad (PPA)
              Index: logarithmplotter
            - Title: Debian / Ubuntu
              Name: debian package (79.5KiB)
              File: python3-logarithmplotter_<version>-1_all.deb
        all:
            - Title: Source code (.tar.gz)
              Name: LogarithmPlotter-v<version>.tar.gz (4.6MiB)
              File: LogarithmPlotter-v<version>.tar.gz
    Footnote: "*LogarithmPlotter requires [Python3](https://python.org/) with [PySide2](https://pypi.org/project/PySide2/) to be installed in order to be launched."
---


